import "@testing-library/jest-dom";
import "@testing-library/jest-dom/extend-expect";
import * as vtl from "@testing-library/vue";
import userEvent from "@testing-library/user-event";
import { Component, Ref } from "vue";
import { axe } from "jest-axe";
import { RunOptions } from "axe-core";
declare const useDefaultProviders: (colorMode: Ref<"light" | "dark">) => void;
export declare type TestRenderProps = {
    [key: string]: any;
    inlineAttrs?: string;
} & Partial<Component>;
declare type A11yOptions = {
    axeOptions?: RunOptions;
};
export interface RenderResult extends vtl.RenderResult {
    asFragment: (innerHTML?: string) => DocumentFragment;
}
/** Render component instance */
export declare const render: (component: Component, ...rest: any | undefined) => RenderResult;
/**
 * Wait for given ms
 *
 * @param {number} duration
 */
declare function waitMs(ms?: number): Promise<unknown>;
/**
 * Get styles from document.styleSheets
 *
 * @param {String} selector
 *
 * @example className usage
 *  getElementStyles('.anyClassName')
 *
 * @example Emotion Classname
 *  const [className1, className2] = [...screen.getByTestId('aspectRatioBox').classList]
 *  const styles = getElementStyles(`.${className1}`)
 *  const pseudoStyles = getElementStyles(`.${className2}:before`)
 */
export declare function getElementStyles(selector: string): string;
/**
 * Validates against common a11y mistakes.
 *
 * Wrapper for jest-axe
 *
 * @example
 * ```ts
 * it('passes a11y test', async () => {
 *  await testA11Y(render(MyComponent));
 * });
 *
 * // sometimes we need to perform interactions first to render conditional UI
 * it('passes a11y test when open', async () => {
 *  const { container } = render(MyComponent, options);
 *
 *  fireEvent.click(screen.getByRole('button'));
 *
 *  await testA11Y(container, options);
 * });
 * ```
 */
export declare const testA11y: (ui: vtl.RenderResult | Element, { axeOptions }?: A11yOptions) => Promise<void>;
export * from "@testing-library/vue";
export { userEvent, waitMs, useDefaultProviders };
export { axe };
//# sourceMappingURL=render.d.ts.map